<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: detail.php 5963 2006-09-26 07:52:15Z yeupou $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
#
#  Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>
#                          Yves Perrin <yves.perrin--cern.ch>
#
#
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

$sql="SELECT * FROM ".ARTIFACT." WHERE bug_id='$item_id' AND group_id='$group_id'";
$fields_per_line=2;
$max_size=40;

$result=db_query($sql);

if (db_numrows($result) > 0)
{
  # ################################ Start the form

  # Defines the item name, converting bugs to bug.
  # (Ideally, the artifact bugs should be named bug)
  $item_name = utils_get_tracker_prefix(ARTIFACT)." #".$item_id;
  # Defines the item link
  $item_link = utils_link("?".$item_id, $item_name);

  # Check whether this item is private or not. If it is private, show only to
  # the submitter
  unset($private_intro);
  if (db_result($result,0,'privacy') == "2")
    {
      if (member_check_private(0, $group_id))
	{
	  # Nothing worth being mentioned
	}
      elseif (db_result($result,0,'submitted_by') == user_getid())
	{
	  $private_intro = _("This item is private. However, you are allowed to read it as you submitted it.");
	}
      else
	{
	  exit_error(_("This item is private."));
	}
    }

  # Check if it is possible for the current user to post a comment. If not
  # add a message
  if (!group_restrictions_check($group_id, ARTIFACT, 2))
    {
      $private_intro .= ' '._("You are not allowed to post comments on this tracker with your current authentification level.");
    }


  trackers_header(array ('title'=>$item_name.", ".utils_cutstring(db_result($result,0,'summary'))));

  print '<p>'.$private_intro.'</p>';

  print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<em>%s</em> overview:"), $item_link).' '.db_result($result,0,'summary').'</h2>';

  print form_header($PHP_SELF, $form_id, "post", 'enctype="multipart/form-data" name="item_form"');
  print form_input("hidden", "func", "postaddcomment");
  print form_input("hidden", "group_id", $group_id);
  print form_input("hidden", "item_id", $item_id);

  # Colspan explanation:
  #
  #  We want the following, twice much space for the value than for the label
  #
  #  | Label:  Value________| Label:  Value______ |
  #  | Label:  Value_____________________________ |
  #
  #  So we have 4 column large via colspan.

  print '

  <table cellpadding="0" width="100%">
      <tr>
          <td class="preinput" width="15%">'._("Submitted by:").'&nbsp;</td>
          <td width="35%">'.utils_user_link(user_getname(db_result($result,0,'submitted_by')), user_getrealname(db_result($result,0,'submitted_by'))).'</td>
          <td colspan="'.($fields_per_line).'" align="center"  width="50%" valign="top"><span class="noprint">'.form_submit(_("Submit Changes").'" class="bold', "submit").'</span></td>
      </tr>
      <tr>
          <td class="preinput" width="15%">'._("Submitted on:").'&nbsp;</td>
          <td width="35%">'.format_date($sys_datefmt,db_result($result,0,'date')).'</td>
          <td colspan="'.($fields_per_line).'" align="center"  width="50%" valign="top">&nbsp;</td>
      </tr>';
  $votes = db_result($result,0,'vote');

  if ($votes)
    {
      # display vote here if any, anything else is handled below
      print '
      <tr>
          <td class="preinput" width="15%">'._("Votes:").'&nbsp;</td>
          <td width="35%"><a href="#votes">'.$votes.'</a></td>
          <td colspan="'.($fields_per_line).'" width="50%">&nbsp;</td>
      </tr>
';

    }

  print '<tr><td colspan="'.($fields_per_line*2).'">&nbsp;</td></tr>';

  # Print special fields
  $i=0;
  $j=0;
  while ( $field_name = trackers_list_all_fields() )
    {
      # if the field is a special field (except summary and details)
      # or if not used by this project  then skip it.
      if ( (!trackers_data_is_special($field_name)  || $field_name=='summary' || $field_name=='details') &&
	   trackers_data_is_used($field_name) )
	{

	  # print the originator email field only if it was posted by
	  # an anonymous user
	  if ($field_name != 'originator_email' ||
	      ($field_name == 'originator_email' && db_result($result,0,'submitted_by') == '100'))
	    {

	  # display the bug field
	  # if field size is greatest than max_size chars then force it to
	  # appear alone on a new line or it wont fit in the page
	      $field_value = db_result($result,0,$field_name);
	      list($sz,) = trackers_data_get_display_size($field_name);

	      if ($field_name == 'details')
		{ $field_value = utils_make_links($field_value); }

	      $field_display = trackers_field_display($field_name,$group_id,$field_value,false,true,true);

	      $label = trackers_field_label_display($field_name,$group_id,false,false);
	      $value = trackers_field_display($field_name,$group_id,$field_value,false,false,true);

              # Save the assigned to value for later.
	      # Also make the user link for this same field
	      if ($field_name == 'assigned_to')
		{
		  $item_assigned_to = trackers_field_display($field_name,$group_id,$field_value,false,false,true);

		  $value = utils_user_link(user_getname($field_value), user_getrealname($field_value));
		}
	      # Details need a specific div
	      if ($field_name == 'details')
		{
		  $value = '<div class="trackersoriginalsubmission">'.$value.'</div>';
		}


              # Fields colors
	      unset($field_class, $row_class);
	      if ($previous_form_bad_fields && array_key_exists($field_name, $previous_form_bad_fields))
		{
                  # We highlight fields that were not properly/completely
		  # filled.
		  $field_class = ' class="highlight"';
		}
	      if ($j % 2 && $field_name != 'details')
		{
		  # We keep the original submission with the default
		  # background color, for lisibility sake
		  #
		  # We also use the boxitem background color only one time
		  # out of two, to keep the page light
		  $row_class = ' class="'.utils_altrow($j+1).'"';
		}

	      if ($sz > $max_size)
		{
		  # Field getting one line for itself

                  # Each time change the background color
		  $j++;

		  print "\n<tr".$row_class.">".
		    '<td valign="middle" '.$field_class.' width="15%">'.$label.'</td>'.
		    '<td valign="middle" '.$field_class.' colspan="'.(2*$fields_per_line-1).'" width="75%">'.
		    $value.'</td>'.
		    "\n</tr>";
		  $i=0;
		}
	      else
		{
                  # Field getting half of a line for itself


		  if (!($i % $fields_per_line))
		    {
		      # Every one out of two, prepare the background color change.
   		      # We do that at this moment because we cannot be sure
 		      # there will be another field on this line.
		      $j++;
		    }

		  print ($i % $fields_per_line ? '':"\n<tr".$row_class.">");
		  print '<td valign="middle"'.$field_class.' width="15%">'.$label.'</td>'.
		    '<td valign="middle"'.$field_class.' width="35%">'.$value.'</td>';
		  $i++;
		  print ($i % $fields_per_line ? '':"\n</tr>");
		}



// 	      if ($sz > $max_size)
// 		{
// 		  print "\n<tr>".
// 		    '<td valign="top" colspan="'.$fields_per_line.'">'.
// 		    $field_display.'</td>'."\n</tr>";
// 		  $i=0;
// 		}
// 	      else
// 		{
// 		  print ($i % $fields_per_line ? '':"\n<tr>");
// 		  print '<td valign="top">'.$field_display.'</td>';
// 		  $i++;
// 		  print ($i % $fields_per_line ? '':"\n</tr>");
// 		}
	    }
        }
    }

  print '</table>';
  print '<p>&nbsp;</p>';

  # ################################ Shortcuts

  print '<div class="noprint"><h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<em>%s</em> details:"), $item_link).'</h2>';
  print '&nbsp;&nbsp;- <a href="#comments">'._("Follow-up Comments").'</a><br />';
  print '&nbsp;&nbsp;- <a href="#attached">'._("Attached Files").'</a><br />';
  print '&nbsp;&nbsp;- <a href="#dependencies">'._("Dependencies").'</a><br />';
  print '&nbsp;&nbsp;- <a href="#cc">'._("Mail Notification Carbon-Copy List").'</a><br />';
  if (trackers_data_is_used("vote"))
    {
      print '&nbsp;&nbsp;- <a href="#votes">'._("Votes").'</a><br />';
    }
  print '&nbsp;&nbsp;- <a href="#history">'._("History").'</a><br />';
  print '<p>&nbsp;</p></div>';


# ################################ Comments

  print '<h3>'.html_anchor(_("Follow-up Comments"), 'comments').'</h3><div class="noprint">';
  if (group_restrictions_check($group_id, ARTIFACT, 2))
   {
     # I18N
     # The sentence will be shown as follows:
     # (Note: you can add pointers to other items by typing artifact #nnn
     # where artifact is one of support, bug, task, patch, recipe, file
     # and nnn is the item id number.)
     printf (_("(Note: you can add pointers to other items by typing %s where %s is one of %s and %s is the item id number.)"),
	  "<em>artifact #nnn</em>",
	  "<em>artifact</em>",
	  "<em>support, bug, task, patch, recipe, file</em>",
	  "<em>nnn</em>");
     print '<p>&nbsp;&nbsp;&nbsp;';
     print trackers_field_textarea('comment','');
     print '<p>';

     if (!user_isloggedin())
       {
         print '<h2 class="warn">'._("You are not logged in").'</h2><p>';
         printf (_("Please %slog in,%s so followups can be emailed to you."),'<a href="'.$GLOBALS['sys_home'].'account/login.php?uri='.urlencode($REQUEST_URI.$extraurl).'">','</a>');
         print '</p>';
       }
     print '<p>&nbsp;</p></div>';
   }

  print show_item_details($item_id,$group_id,0,$item_assigned_to);

  print '<p>&nbsp;</p>';

  # ################################ Attached Files

  print '<h3>'.html_anchor(_("Attached Files"), "attached").'</h3>';

  if (group_restrictions_check($group_id, ARTIFACT, 2))
   {
     print '<p class="noprint">';
     print sprintf(_("(Note: file size limit is set to %s kB, after insertion of the required escape characters.)"), $GLOBALS['sys_upload_max']);
     print '</p><p class="noprint"><span class="preinput"> '._("Attach File:").'</span><br />
      &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40" />
      <br />
      <span class="preinput">'._("File Description:").'</span><br />
      &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255" />
      </p><p>';
   }

  print show_item_attached_files($item_id,$group_id);

  print '</p><p>&nbsp;</p>';

  # ################################ Dependancies

  print '<h3>'.html_anchor(_("Dependencies"), "dependencies").'</h3>';

  print show_item_dependency($item_id);

  print '<p></p>';

  print show_dependent_item($item_id);

  print '<p>&nbsp;</p>';

  # ################################ Mail notification

  print '<h3>'.html_anchor(_("Mail Notification Carbon-Copy List"), "cc").'</h3>';
  if (user_isloggedin())
    {
      print '<p class="noprint">';
      printf (_("(Note: for %s users, you can use their login name rather than their email addresses.)"), $GLOBALS['sys_name']);
      print '</p><p class="noprint">
	   <span class="preinput">'._("Add Email Addresses (comma as separator):").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="30" /><br />
	   <span class="preinput">'._("Comment:").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255" /><p>';
    }

  show_item_cc_list($item_id, $group_id);

  print '<p>&nbsp;</p>';

  # ################################ Votes

  if (trackers_data_is_used("vote"))
    {
         print '<h3>'.html_anchor(_("Votes"), "votes").'</h3>';
      print '<p>'.sprintf(ngettext("There is %s vote so far.", "There are %s votes so far.", $votes), $votes).' '._("Votes easily highlight which items people would like to see resolved in priority, independantly of the priority of the item set by tracker managers.").'</p><p class="noprint">';

      if (trackers_data_is_showed_on_add("vote") || member_check(user_getid(), $group_id))
        {

          if (user_isloggedin())
            {

              $votes_given = trackers_votes_user_giventoitem_count(user_getid(), ARTIFACT, $item_id);
              $votes_remaining = trackers_votes_user_remains_count(user_getid()) + $votes_given;
              if (!$new_vote)
                { $new_vote = $votes_given; }

              # Show how many vote he already gave and allows to remove
              # or give more
              # votes.
              # The number of remaining points must be 100 - others votes

              print '<span class="preinput">'._("Your vote:").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="new_vote" size="3" maxlength="3" value="'.$new_vote.'" /> '.sprintf(ngettext("/ %s remaining vote", "/ %s remaining votes", $votes_remaining), $votes_remaining);
              print '</p>';
            }
          else
            {
              print '<span class="warn">'._("Only logged-in users can vote.").'</span></p>';
            }
         }
       else
         {
            print '<span class="warn">'._("Only project members can vote.").'</span></p>';
         }

        print '<p>&nbsp;</p>';
    }


  #  ################################  Submit

  print '<div align="center" class="noprint">'.form_submit(_("Submit Changes").'" class="bold', "submit").'</form></div>
';



  # History

  print '<p>&nbsp;</p><p>&nbsp;</p>';
  show_item_history($item_id,$group_id);

  trackers_footer(array());
}
else
{
  exit_error(_("No item found with that id."));
}


?>
